@@ -1,4 +1,5 @@
 import sys
+import six
 
 from django.utils.translation import ugettext_lazy as _
 from django.core.exceptions import ImproperlyConfigured
@@ -9,7 +10,7 @@ class Setting(object):
 
     def __init__(self, default=SENTINEL, definition='', names=None):
         self.names = names or []
-        if isinstance(self.names, basestring):
+        if isinstance(self.names, six.string_types):
             self.names = [self.names]
         self.names = set(self.names)
         self.default = default
@@ -122,6 +123,7 @@ default_settings = dict(
     A2_USERNAME_HELP_TEXT=Setting(default=None, definition='Help text to explain validation rules of usernames'),
     IDP_BACKENDS=[],
     AUTH_FRONTENDS=[],
+    AUTH_FRONTENDS_KWARGS={},
     VALID_REFERERS=Setting(default=[], definition='List of prefix to match referers'),
     A2_OPENED_SESSION_COOKIE_NAME=Setting(default='A2_OPENED_SESSION', definition='Authentic session open'),
     A2_OPENED_SESSION_COOKIE_DOMAIN=Setting(default=None),
