@@ -11,6 +11,7 @@ import pickle
 import base64
 import urllib
 import itertools
+import six
 
 # code originaly copied from by now merely inspired by
 # http://www.amherst.k12.oh.us/django-ldap.html
@@ -23,10 +24,7 @@ from django.contrib.auth.models import Group
 from django.db import DatabaseError
 from django.db import transaction
 
-try:
-    import lasso
-except ImportError:
-    pass
+from authentic2.compat import lasso
 
 from authentic2.decorators import to_list
 from authentic2.compat import get_user_model, commit_on_success
@@ -61,7 +59,7 @@ _DEFAULTS = {
     # do not try to get a Django user from the LDAP user
     # it's incompatible with a lot of Django applications, the
     # django.contrib.admin for example
-    'transient': True,
+    'transient': False,
     # active directory ?
     'active_directory': False,
     # shuffle replicas
@@ -93,11 +91,13 @@ _DEFAULTS = {
     # keep password around so that Django authentification also work
     'clean_external_id_on_update': True,
     # Conserve the passsword in the Django User object
-    'keep_password': True,
+    'keep_password': False,
     # Only authenticate users coming from the corresponding realm
     'limit_to_realm': False,
     # Assign users mandatorily to some groups
     'set_mandatory_groups': (),
+    # Can users change their password ?
+    'user_can_change_password': True,
 }
 
 _REQUIRED = ('url', 'basedn')
@@ -190,14 +190,30 @@ class LDAPUser(get_user_model()):
             raise LDAPException('missing password for dn %r', self.dn)
         return password
 
+    def check_password(self, raw_password):
+        connection = get_connection(self.block)
+        try:
+            connection.simple_bind_s(self.dn, raw_password.encode('utf-8'))
+        except ldap.INVALID_CREDENTIALS:
+            return False
+        except ldap.LDAPError, e:
+            log.error('LDAPUser.check_password() failed: %s', e)
+            return False
+        return True
+
     def set_password(self, new_password):
         old_password = self.get_ldap_password()
         if old_password != new_password:
             conn = self.get_connection()
-            modify_password(conn, self.block, self.dn, self.get_ldap_password(),
-                    new_password)
+            modify_password(conn, self.block, self.dn, old_password, new_password)
         self.set_ldap_password(new_password)
-        super(LDAPUser, self).set_password(new_password)
+        if self.block['keep_password']:
+            super(LDAPUser, self).set_password(new_password)
+        else:
+            self.set_unusable_password()
+
+    def has_usable_password(self):
+        return self.block['user_can_change_password']
 
     def get_connection(self):
         return get_connection(self.block, (self.dn, self.get_ldap_password()))
@@ -251,8 +267,8 @@ class LDAPBackend(object):
                 if d not in block:
                     block[d] = _DEFAULTS[d]
                 else:
-                    if isinstance(_DEFAULTS[d], basestring):
-                        if not isinstance(block[d], basestring):
+                    if isinstance(_DEFAULTS[d], six.string_types):
+                        if not isinstance(block[d], six.string_types):
                             raise ImproperlyConfigured('LDAP_AUTH_SETTINGS: '
                                     'attribute %r must be a string' % d)
                         try:
@@ -273,19 +289,19 @@ class LDAPBackend(object):
                         raise ImproperlyConfigured('LDAP_AUTH_SETTINGS: '
                                 'attribute %r is required but is empty')
             for i in _TO_ITERABLE:
-                if isinstance(block[i], basestring):
+                if isinstance(block[i], six.string_types):
                     block[i] = (block[i],)
             # lowercase LDAP attribute names
             block['external_id_tuples'] = map(lambda t: map(str.lower, map(str, t)), block['external_id_tuples'])
             block['attribute_mappings'] = map(lambda t: map(str.lower, map(str, t)), block['attribute_mappings'])
             for key in _TO_LOWERCASE:
                 # we handle strings, list of strings and list of list or tuple whose first element is a string
-                if isinstance(block[key], basestring):
+                if isinstance(block[key], six.string_types):
                     block[key] = str(block[key]).lower()
                 elif isinstance(block[key], (list, tuple)):
                     new_seq = []
                     for elt in block[key]:
-                        if isinstance(elt, basestring):
+                        if isinstance(elt, six.string_types):
                             elt = str(elt).lower()
                         elif isinstance(elt, (list, tuple)):
                             elt = list(elt)
@@ -353,7 +369,7 @@ class LDAPBackend(object):
                 self.try_admin_bind(conn, block)
                 if block['user_dn_template']:
                     template = str(block['user_dn_template'])
-                    escaped_username = escape_dn_chars(username)
+                    escaped_username = escape_dn_chars(utf8_username)
                     authz_ids.append(template.format(username=escaped_username))
                 else:
                     try:
@@ -374,6 +390,7 @@ class LDAPBackend(object):
                             results = conn.search_s(user_basedn, ldap.SCOPE_SUBTREE, query)
                             # remove search references
                             results = [ result for result in results if result[0] is not None]
+                            log.debug('found dns %r', results)
                             if len(results) == 0:
                                 log.debug('user lookup failed: no entry found, %s' % query)
                             elif not block['multimatch'] and len(results) > 1:
@@ -391,7 +408,7 @@ class LDAPBackend(object):
                         continue
                     except ldap.LDAPError, e:
                         log.error('user lookup failed: with query %r got error '
-                                '%s', username, query, e)
+                                '%s: %s', username, query, e)
                         continue
                 if not authz_ids:
                     continue
@@ -410,7 +427,7 @@ class LDAPBackend(object):
                         continue
                 except ldap.NO_SUCH_OBJECT:
                     # should not happen as we just searched for this object !
-                    log.error('user bind failed: authz_id not found %s' % ', '.join(authz_ids))
+                    log.error('user bind failed: authz_id not found %r', ', '.join(authz_ids))
                     if block['replicas']:
                         break
                 return self._return_user(uri, authz_id, username, password, conn, block)
@@ -544,7 +561,8 @@ class LDAPBackend(object):
                         group_filter.format(user_dn=escape_filter_chars(dn)), [])
             except ldap.NO_SUCH_OBJECT:
                 pass
-            group_dns.update(dn for dn, attributes in results)
+            else:
+                group_dns.update(dn for dn, attributes in results)
         return group_dns
 
     def populate_user_groups(self, user, uri, dn, conn, block):
@@ -763,22 +781,24 @@ class LDAPBackend(object):
         user = LDAPUser(username=username)
         user.ldap_init(block, dn, password, transient=True)
         self.populate_user(user, uri, dn, username, conn, block, attributes)
-        user.set_password(password)
         user.pk = 'transient!{0}'.format(base64.b64encode(pickle.dumps(user)))
         return user
 
     def _return_django_user(self, uri, dn, username, password, conn, block, attributes):
         user = self.lookup_existing_user(uri, dn, username, password, conn, block, attributes)
         if user:
+            created = False
             log.debug('found existing user %r', user)
         else:
+            created = True
             user = LDAPUser()
         user.ldap_init(block, dn, password)
+        self.populate_user(user, uri, dn, username, conn, block, attributes)
         if block['keep_password']:
-            user.set_password(password)
+            if created:
+                user.set_password(password)
         else:
             user.set_unusable_password()
-        self.populate_user(user, uri, dn, username, conn, block, attributes)
         self.save_user(user, username)
         user.keep_pk = user.pk
         user.pk = 'persistent!{0}'.format(base64.b64encode(pickle.dumps(user)))
