@@ -25,7 +25,7 @@ import random
 import string
 from functools import wraps
 
-import lasso
+from authentic2.compat import lasso
 from django.core.urlresolvers import reverse
 from django.contrib.auth.decorators import login_required
 from django.core.exceptions import ObjectDoesNotExist
@@ -440,11 +440,12 @@ def sso(request):
                         logger=logger, warning=True)
                 logger.info('provider %s loaded with success' \
                     % provider_id)
-            if provider_loaded.service_provider.policy.authn_request_signature_check_hint == lasso.PROFILE_SIGNATURE_VERIFY_HINT_IGNORE:
-                    signed = False
-            login.setSignatureVerifyHint(
-                    provider_loaded.service_provider.policy \
-                            .authn_request_signature_check_hint)
+            if policy.authn_request_signed:
+                verify_hint = lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE
+            else:
+                verify_hint = lasso.PROFILE_SIGNATURE_VERIFY_HINT_IGNORE
+                signed = False
+            login.setSignatureVerifyHint(verify_hint)
     if signed and not check_destination(request, login.request):
         logger.warning('wrong or absent destination')
         return return_login_error(request, login,
@@ -1106,10 +1107,10 @@ def process_logout_request(request, message, binding):
                     'slo unknown provider %s' % logout.remoteProviderId)
                 return logout, return_logout_error(request, logout,
                         AUTHENTIC_STATUS_CODE_UNKNOWN_PROVIDER)
+            policy = get_sp_options_policy(p)
             # we do not verify authn request, why verify logout requests...
-            logout.setSignatureVerifyHint(
-                    p.service_provider.policy \
-                            .authn_request_signature_check_hint)
+            if not policy.authn_request_signed:
+                logout.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_IGNORE)
             logout.processRequestMsg(message)
     except lasso.DsError:
         logger.error(''
@@ -1567,9 +1568,10 @@ def slo_return(request):
     provider_id = logout.remoteProviderId
     # forced to reset signature_verify_hint as it is not saved in the dump
     provider = load_provider(request, provider_id, server=server)
-    policy = provider.service_provider.get_policy()
+    policy = get_sp_options_policy(provider)
     # FIXME: should use a logout_request_signature_check_hint
-    logout.setSignatureVerifyHint(policy.authn_request_signature_check_hint)
+    if not policy.authn_request_signed:
+        logout.setSignatureVerifyHint(lasso.PROFILE_SIGNATURE_VERIFY_HINT_IGNORE)
     if not load_provider(request, provider_id, server=logout.server):
         logger.warning('failed to load provider %r', provider_id)
     return process_logout_response(request, logout,
