@@ -1,6 +1,7 @@
 import datetime as dt
 
 from django.db import models
+from django.utils import timezone
 
 __all__ = ('Nonce',)
 
@@ -8,7 +9,7 @@ _NONCE_LENGTH_CONSTANT = 256
 
 class NonceManager(models.Manager):
     def cleanup(self, now=None):
-        now = now or dt.datetime.now()
+        now = now or timezone.now()
         self.filter(not_on_or_after__lt=now).delete()
 
 class Nonce(models.Model):
