@@ -2,8 +2,11 @@ import xml.etree.ElementTree as etree
 import hashlib
 import numbers
 import datetime
+import six
+
+import requests
+from authentic2.compat import lasso
 
-import lasso
 from django.db import models
 from django.db.models import Q
 from django.conf import settings
@@ -20,7 +23,6 @@ try:
 except ImportError:
     from django.contrib.contenttypes.generic import GenericRelation
 
-
 from fields import PickledObjectField, MultiSelectField
 
 from . import app_settings, managers
@@ -140,28 +142,6 @@ SIGNATURE_VERIFY_HINT = {
         lasso.PROFILE_SIGNATURE_VERIFY_HINT_FORCE: _('Always check signatures'),
         lasso.PROFILE_SIGNATURE_VERIFY_HINT_IGNORE: _('Does not check signatures') }
 
-class LibertyProviderPolicy(models.Model):
-    name = models.CharField(max_length=64, unique=True)
-    authn_request_signature_check_hint = models.IntegerField(
-            verbose_name=_("How to verify signatures Authentication Request ?"),
-            choices=SIGNATURE_VERIFY_HINT.items(),
-            default=lasso.PROFILE_SIGNATURE_VERIFY_HINT_MAYBE)
-
-    objects = a2_managers.GetByNameManager()
-
-    def natural_key(self):
-        return (self.name,)
-
-    def __unicode__(self):
-        options = []
-        options.append(u'AuthnRequest signature: %s' % SIGNATURE_VERIFY_HINT[self.authn_request_signature_check_hint])
-        return self.name + ' (%s)' % ', '.join(options)
-
-    class Meta:
-        verbose_name = _('SAML service provider policy')
-        verbose_name_plural = _('SAML service provider policies')
-
-
 AUTHSAML2_UNAUTH_PERSISTENT = (
     ('AUTHSAML2_UNAUTH_PERSISTENT_ACCOUNT_LINKING_BY_AUTH',
         _('Account linking by authentication')),
@@ -391,7 +371,7 @@ class SAMLAttribute(models.Model):
         if self.friendly_name:
             at.friendlyName = self.friendly_name.encode('utf-8')
         values = ctx.get(self.attribute_name)
-        if isinstance(values, (basestring, numbers.Number, datetime.datetime, datetime.date)):
+        if isinstance(values, tuple(six.string_types) + (numbers.Number, datetime.datetime, datetime.date)):
             values = [values]
         elif isinstance(values, (tuple, list)):
             pass
@@ -471,6 +451,7 @@ class LibertyProvider(models.Model):
     slug = models.SlugField(max_length=140, unique=True)
     entity_id = models.URLField(unique = True)
     entity_id_sha1 = models.CharField(max_length = 40, blank=True)
+    metadata_url = models.URLField(max_length=256, blank=True)
     protocol_conformance = models.IntegerField(max_length = 10,
             choices = ((lasso.PROTOCOL_SAML_2_0, 'SAML 2.0'),))
     metadata = models.TextField(validators = [ metadata_validator ])
@@ -508,6 +489,18 @@ class LibertyProvider(models.Model):
     def natural_key(self):
         return (self.slug,)
 
+    def update_metadata(self):
+        try:
+            if not self.metadata_url:
+                raise ValidationError(_('No metadata URL'))
+            response = requests.get(self.metadata_url)
+        except requests.RequestException, e:
+            raise ValidationError(_('Retrieval of metadata failed: %s') % e)
+        else:
+            self.metadata = response.content
+            self.clean()
+            self.save()
+
     class Meta:
         ordering = ('name',)
         verbose_name = _('SAML provider')
@@ -536,8 +529,6 @@ class LibertyServiceProvider(models.Model):
     enable_following_sp_options_policy = models.BooleanField(verbose_name = \
         _('The following options policy will apply except if a policy for all service provider is defined.'))
     sp_options_policy = models.ForeignKey(SPOptionsIdPPolicy, related_name = "sp_options_policy", verbose_name = _('service provider options policy'), blank=True, null=True)
-    policy = models.ForeignKey(LibertyProviderPolicy,
-            verbose_name=_("Protocol policy"), null=True, default=1)
     enable_following_attribute_policy = models.BooleanField(verbose_name = \
         _('The following attribute policy will apply except if a policy for all service provider is defined.'))
     attribute_policy = models.ForeignKey('idp.AttributePolicy',
@@ -550,9 +541,6 @@ class LibertyServiceProvider(models.Model):
 
     objects = managers.GetByLibertyProviderManager()
 
-    def get_policy(self):
-        return get_all_custom_or_default(self, 'policy')
-
     def natural_key(self):
         return (self.liberty_provider.slug,)
 
