@@ -42,7 +42,7 @@ def to_int(name, default):
         raise ImproperlyConfigured('environ variable %s must be an integer' % name)
 
 
-DEBUG = to_boolean('DEBUG', default=False)
+DEBUG = to_boolean('DEBUG', default=True)
 DEBUG_PROPAGATE_EXCEPTIONS = to_boolean('DEBUG_PROPAGATE_EXCEPTIONS', default=False)
 USE_DEBUG_TOOLBAR = to_boolean('USE_DEBUG_TOOLBAR', default=False)
 TEMPLATE_DEBUG = DEBUG
@@ -108,6 +108,7 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     'django.contrib.messages.context_processors.messages',
     'django.core.context_processors.static',
     'authentic2.context_processors.a2_processor',
+    'sekizai.context_processors.sekizai',
 )
 
 MIDDLEWARE_CLASSES = (
@@ -193,6 +194,7 @@ INSTALLED_APPS = (
     'authentic2.manager',
     'authentic2',
     'gadjo',
+    'sekizai',
 )
 
 INSTALLED_APPS = plugins.register_plugins_installed_apps(INSTALLED_APPS)
@@ -356,22 +358,9 @@ if 'LDAP_AUTH_SETTINGS' in os.environ:
         raise ImproperlyConfigured('LDAP_AUTH_SETTINGS is not a JSON document', e)
 else:
     LDAP_AUTH_SETTINGS = []
-##################################
-# Cache configuration
-##################################
-CACHE_DIR = os.path.join('/var/cache/', PROJECT_NAME)
-if not os.access(CACHE_DIR, os.W_OK):
-    CACHE_DIR = os.path.join(PROJECT_DIR, 'cache')
-    warnings.warn('Cannot access global cache path, using in project cache directory %s' %  CACHE_DIR)
-    if not os.path.isdir(CACHE_DIR):
-        os.makedirs(CACHE_DIR)
 
-CACHES = {
-    'default': {
-        'BACKEND': 'django.core.cache.backends.filebased.FileBasedCache',
-        'LOCATION': CACHE_DIR,
-    },
-}
+CACHES = global_settings.CACHES
+
 if 'CACHE_BACKEND' in os.environ:
     CACHES['default'] = json.loads(os.environ['CACHE_BACKEND'])
 
@@ -477,8 +466,8 @@ for config_dir in CONFIG_DIRS:
 try:
     from local_settings import *
 except ImportError, e:
-    if 'local_settings' in e.args[0]:
-        pass
+    if not 'local_settings' in e.args[0]:
+        raise
 
 if 'IDP_SAML2' in globals():
     A2_IDP_SAML2_ENABLE = IDP_SAML2
@@ -539,18 +528,22 @@ LOGGING = {
         },
         'lasso': {
                 'handlers': ['mail_admins', 'syslog'],
-                'level': 'INFO',
+                'level': 'WARNING',
                 'propagate': False,
         },
         '': {
                 'handlers': ['mail_admins', 'syslog'],
-                'level': 'INFO',
+                'level': 'WARNING',
         },
     },
 }
 
 if DEBUG and not DEBUG_LOG:
-    LOGGING['loggers']['']['level'] = 'DEBUG'
+    for logger in LOGGING['loggers']:
+        if logger.startswith('authentic2'):
+            LOGGING['loggers'][logger]['level'] = 'DEBUG'
+            LOGGING['loggers'][logger]['propagate'] = False
+            LOGGING['loggers'][logger]['handlers'] = LOGGING['loggers']['']['handlers']
 
 if to_boolean('CONSOLE_LOG'):
     LOGGING['loggers']['']['handlers'] += ['console']
