@@ -23,18 +23,9 @@ not_homepage_patterns += patterns('',
     url(r'^admin/', include(admin.site.urls)),
     url(r'^admin_tools/', include('admin_tools.urls')),
     url(r'^idp/', include('authentic2.idp.urls')),
-    url(r'^manager/', include('authentic2.manager.urls')),
+    url(r'^manage/', include('authentic2.manager.urls')),
 )
 
-if getattr(settings, 'AUTH_OPENID', False):
-    not_homepage_patterns += patterns('',
-        (r'^accounts/openid/',
-            include('authentic2.auth2_auth.auth2_openid.urls')),
-    )
-
-if getattr(settings, 'AUTH_SSL', False):
-    not_homepage_patterns += patterns('',
-        url(r'^accounts/sslauth/', include('authentic2.auth2_auth.auth2_ssl.urls')))
 
 urlpatterns += not_homepage_patterns
 
@@ -50,5 +41,14 @@ if settings.DEBUG:
     urlpatterns += patterns('django.contrib.staticfiles.views',
         url(r'^static/(?P<path>.*)$', 'serve'),
     )
+ 
+if settings.USE_DEBUG_TOOLBAR:
+    try:
+        import debug_toolbar
+        urlpatterns += patterns('',
+            url(r'^__debug__/', include(debug_toolbar.urls)),
+        )
+    except ImportError:
+        pass
 
 urlpatterns = plugins.register_plugins_urls(urlpatterns)
